@@ -2,6 +2,7 @@
 
 thread_template = '''from zoo_framework.threads import BaseThread
 
+
 class {{thread_name.title()}}Thread(BaseThread):
     def __init__(self):
         BaseThread.__init__(self, {
@@ -13,11 +14,28 @@ class {{thread_name.title()}}Thread(BaseThread):
     def _execute(self):
         pass
 
-    def _destroy(self,result):
+    def _destroy(self, result):
         pass
 
     def _on_error(self):
         pass
 
     def _on_done(self):
-        pass'''
\ No newline at end of file
+        pass'''
+
+thread_mod_insert_template = """
+\r\nfrom .{{thread_name}}_thread import {{thread_name.title()}}Thread
+"""
+
+main_template = """
+from zoo_framework.core import Master
+
+
+def main():
+    master = Master(worker_count=5)
+    master.run()
+
+
+if __name__ == '__main__':
+    main()
+"""
\ No newline at end of file
